# pymixing
pymixing is a python audio processing / analysis library based on soundfile, numpy, librosa, and pyloudnorm.Inspired by traditional console and digital audio workstations, it aims to provide audio experts with flexible assistance to deal with the complex audio processing / detection tasks.
Currently, pymixing can not only supports the mono files in wav format, but also the stereo files. Besides，it is already possible to export the corresponding 48k / 24bit or 44.1k/16bit wav format mono/stereo audio files as required.
